@@ -18,14 +18,13 @@ Demo service handler
 """
 from __future__ import division
 
+import importlib_resources
 import os
-import pkg_resources
 import mimetypes
 from collections import defaultdict
 
 from mapproxy.config.config import base_config
 from mapproxy.util.ext.odict import odict
-from mapproxy.compat import PY2
 from mapproxy.exception import RequestError
 from mapproxy.service.base import Server
 from mapproxy.response import Response
@@ -33,18 +32,16 @@ from mapproxy.srs import SRS, get_epsg_num
 from mapproxy.layer import SRSConditional, CacheMapLayer, ResolutionConditional
 from mapproxy.source.wms import WMSSource
 
-if PY2:
-    import urllib2
-else:
-    from urllib import request as urllib2
+from urllib import request as urllib2
 
 from mapproxy.template import template_loader, bunch
 env = {'bunch': bunch}
-get_template = template_loader(__name__, 'templates', namespace=env)
+get_template = template_loader(__package__, 'templates', namespace=env)
 
 # Used by plugins
 extra_demo_server_handlers = set()
 
+
 def register_extra_demo_server_handler(handler):
     """ Method used by plugins to register a new handler for the demo service.
         The handler passed to this method is invoked by the DemoServer.handle()
@@ -61,6 +58,7 @@ def register_extra_demo_server_handler(handler):
 
 extra_substitution_handlers = set()
 
+
 def register_extra_demo_substitution_handler(handler):
     """ Method used by plugins to register a new handler for doing substitutions
         to the HTML template used by the demo service.
@@ -71,7 +69,8 @@ def register_extra_demo_substitution_handler(handler):
         services.
 
         :param handler: New handler for incoming requests
-        :type handler: function that takes 3 arguments(DemoServer instance, req and a substitutions dictionary argument).
+        :type handler: function that takes 3 arguments(DemoServer instance, req and a substitutions dictionary
+            argument).
     """
 
     extra_substitution_handlers.add(handler)
@@ -81,12 +80,14 @@ def static_filename(name):
     if base_config().template_dir:
         return os.path.join(base_config().template_dir, name)
     else:
-        return pkg_resources.resource_filename(__name__, os.path.join('templates', name))
+        return importlib_resources.files(__package__).joinpath('templates').joinpath(name)
+
 
 class DemoServer(Server):
     names = ('demo',)
+
     def __init__(self, layers, md, request_parser=None, tile_layers=None,
-                 srs=None, image_formats=None, services=None, restful_template=None, background = None):
+                 srs=None, image_formats=None, services=None, restful_template=None, background=None):
         Server.__init__(self)
         self.layers = layers
         self.tile_layers = tile_layers or {}
@@ -269,7 +270,7 @@ class DemoServer(Server):
                                    layer_srs=self.layer_srs,
                                    bbox=bbox,
                                    res=min_res,
-                                   background_url = background_url)
+                                   background_url=background_url)
 
     def _render_tms_template(self, template, req):
         template = get_template(template, default_inherit="demo/static.html")
@@ -303,7 +304,7 @@ class DemoServer(Server):
                                    units=units,
                                    add_res_to_options=add_res_to_options,
                                    all_tile_layers=self.tile_layers,
-                                   background_url = background_url)
+                                   background_url=background_url)
 
     def _render_wmts_template(self, template, req):
         template = get_template(template, default_inherit="demo/static.html")
@@ -332,13 +333,13 @@ class DemoServer(Server):
                                    units=units,
                                    all_tile_layers=self.tile_layers,
                                    restful_url=restful_url,
-                                   background_url = background_url)
+                                   background_url=background_url)
 
     def _render_capabilities_template(self, template, xmlfile, service, url):
         template = get_template(template, default_inherit="demo/static.html")
-        return template.substitute(capabilities = xmlfile,
-                                   service = service,
-                                   url = url)
+        return template.substitute(capabilities=xmlfile,
+                                   service=service,
+                                   url=url)
 
     def authorized_demo(self, environ):
         if 'mapproxy.authorize' in environ:
